<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 30, 2020
 */

/**
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
abstract class Model_RecoveryPoint_Files extends Model_RecoveryPoint_Abstract
{
    const RECOVERY_DIR_NAME = 'acronis_temp';
    const NW_DOWNLOAD_DIR_PATH = '/home/' . self::RECOVERY_DIR_NAME;
    const DIR_ID = 'id';
    const DIR_CONTENT = 'content';

    /**
     * @param array   $dirIds
     * @param boolean $deleteNewerFiles
     */
    protected function _recoverDirectories(array $dirIds, $deleteNewerFiles = false)
    {
        $Api =  $this->_getApi();

        if ($deleteNewerFiles) {
            $this->_deleteNewerFiles($dirIds);
        }

        $Api->recoverDirectories($this->getAgentTenantId(), $dirIds);
    }

    /**
     * Delete newer files if directory.
     *
     * @param array $dirIds
     */
    protected function _deleteNewerFiles(array $dirIds)
    {
        $this->_getApi()->deleteFilesCreatedAfter($this->getCreated());

        foreach ($dirIds as $dirId) {
            $this->_deleteNewContentIfDir($dirId);
        }
    }

    /**
     * Delete new content if directory.
     *
     * @param string $id
     */
    private function _deleteNewContentIfDir($id)
    {
        $dir = $this->_getCache()->getFileDetails($this->getBackupId(), $id);
        if ($dir['type'] === 'dir') {
            $path = $dir['displayPath'];
            $this->_getApi()->addPathDeleteAfter($path);
        }
    }


    /**
     * @param array $paths
     */
    protected function _getDirIdsByPaths(array $paths)
    {
        $ids = array();
        foreach ($paths as $path) {
            $path = ltrim($path, '/');
            $dir = $this->_getDirByPath($path);
            $ids[] = $dir[self::DIR_ID];
        }

        return $ids;
    }

    /**
     * Create dirs for restoring to alt location & downloading content.
     *
     * @param string $path
     */
    protected function _createRestoreAltLocationDir($path)
    {
        if (!$this->_isDir($path)) {
            $mkdirCommand = "mkdir -p $path && chmod 0755 $path";
            $Command = new Command($mkdirCommand);
            $Command->runAsRoot();
            $Command->exec();
        }
    }
}
